Foxtrott has uploaded a new change for review. ( 
https://gerrit.wikimedia.org/r/353303 )

Change subject: Add styling to summary input
......................................................................

Add styling to summary input

Change-Id: I18b732280084d54c30878d834ac3a36343174f63
---
M DataTransfer.php
M specials/DT_ImportCSV.php
2 files changed, 8 insertions(+), 1 deletion(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/extensions/DataTransfer 
refs/changes/03/353303/1

diff --git a/specials/DT_ImportCSV.php b/specials/DT_ImportCSV.php
index 332224e..71c5651 100644
--- a/specials/DT_ImportCSV.php
+++ b/specials/DT_ImportCSV.php
@@ -31,6 +31,7 @@
                        $text = $this->printForm();
                }
 
+               $this->getOutput()->addModuleStyles( 'ext.datatransfer');
                $this->getOutput()->addHTML( $text );
        }
 

diff --git a/DataTransfer.php b/DataTransfer.php
index 84348e2..16253c6 100644
--- a/DataTransfer.php
+++ b/DataTransfer.php
@@ -24,13 +24,19 @@
 );
 
 ###
 # This is the path to your installation of Semantic Forms as
 # seen on your local filesystem. Used against some PHP file path
 # issues.
 ##
 $dtgIP = dirname( __FILE__ );
 ##
 
+$wgResourceModules[ 'ext.datatransfer' ] = array(
+    'localBasePath' => $dtgIP,
+    'styles' => 'styles/DataTransfer.css',
+    'position' => 'bottom',
+);
+
 // register all special pages and other classes
 $wgAutoloadClasses['DTPageStructure'] = $dtgIP . 
@@ -24,13 +24,19 @@
 
 ###
-# This is the path to your installation of Semantic Forms as
+# This is the path to your installation of DataTransfer as
 # seen on your local filesystem. Used against some PHP file path
 # issues.
'/includes/DT_PageStructure.php';
 $wgAutoloadClasses['DTPageComponent'] = $dtgIP . 
'/includes/DT_PageStructure.php';
-- 
To view, visit https://gerrit.wikimedia.org/r/353303
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I18b732280084d54c30878d834ac3a36343174f63
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/DataTransfer
Gerrit-Branch: master
Gerrit-Owner: Foxtrott <s7ep...@gmail.com>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to